@@ -18,18 +18,25 @@ class ObjDump                       // merely calls 'objdump',
         void start();
 };
 
-class ObjDump::const_iterator: 
-                public std::iterator<std::input_iterator_tag, std::string>
+struct ObjDump::const_iterator
+                // public std::iterator<std::input_iterator_tag, std::string>
 {
     friend const_iterator ObjDump::begin();
     friend const_iterator ObjDump::end();
 
-    FBB::Process *d_process;
-
-    mutable bool d_iterate;
-    mutable std::string d_line;
-
-    const_iterator(FBB::Process *process, bool iterate);
+    using iterator_category = std::input_iterator_tag;
+    using difference_type   = std::ptrdiff_t;
+    using value_type        = std::string;
+    using pointer           = value_type *;
+    using reference         = value_type &;
+    
+    private:
+        FBB::Process *d_process;
+    
+        mutable bool d_iterate;
+        mutable std::string d_line;
+    
+        const_iterator(FBB::Process *process, bool iterate);
 
     public:
         const_iterator &operator++();
